@@ -109,6 +109,9 @@ if __name__ == '__main__':
 	elif options.frontend == "mixed":
 		from Visualizations import PygameMixedVisualizations
 		visual = PygameMixedVisualizations(w,h)
+	else:
+		from Visualizations import DefaultVisualization
+		visual = DefaultVisualization()
 
 	if options.list != None:
 		if options.list == "ensembles" or \
