@@ -43,16 +43,22 @@ class Instrument:
 			b.set_meter(state["meter"])
 			b.key = state["key"]
 			self.bar = b
-
+		
+		dur = state["resolution"]
+		if state["swing"]:
+			if state["tick"] % 2 == 0:
+				dur *= 1.33
+			else:
+				dur *= 0.66
 		if len(self.bar) > 0:
 			if self.bar[0][2] is None:
-				i = 1 / (1.0 / state["resolution"] + \
+				i = 1 / (1.0 / dur + \
 					1.0 / self.bar[0][1])
 				self.bar[0][1] = i
 			else:
-				self.bar.place_notes(None, state["resolution"])
+				self.bar.place_notes(None, dur)
 		else:
-			self.bar.place_notes(None, state["resolution"])
+			self.bar.place_notes(None, dur)
 		self.last_tick = (state["iterations"], state["tick"])
 
 
@@ -70,6 +76,7 @@ class Instrument:
 				self.track + self.bar
 			b = Bar()
 			b.set_meter(state["meter"])
+			b.length = 0.0
 			b.key = state["key"]
 			self.bar = b
 		let_ring = False
@@ -81,6 +88,12 @@ class Instrument:
 		#	else:
 		#		let_ring = True
 
+		dur = state["resolution"]
+		if state["swing"]:
+			if state["tick"] % 2 == 0:
+				dur *= 0.66
+			else:
+				dur *= 1.33
 
 		n = self.generate_note(state)
 		v = self.generate_velocity(state)
@@ -91,7 +104,8 @@ class Instrument:
 
 			# Record played notes in a Track
 			if self.last_tick != (state["iterations"], state["tick"]):
-				self.bar.place_notes(n, state["resolution"])
+				self.bar.place_notes(n, dur)
+				
 			else:
 				self.bar.bar[-1][2].add_notes(n)
 
@@ -106,13 +120,14 @@ class Instrument:
 		else:
 			if len(self.bar) > 0:
 				if self.bar[-1][1] is None:
-					i = 1 / (1.0 / state["resolution"] + \
+					i = 1 / (1.0 / dur + \
 						1.0 / self.bar[-1][1])
 					self.bar[-1][1] = i
+					print i
 				else:
-					self.bar.place_notes(None, state["resolution"])
+					self.bar.place_notes(None, dur)
 			else:
-				self.bar.place_notes(None, state["resolution"])
+				self.bar.place_notes(None, dur)
 
 		self.last_tick = (state["iterations"], state["tick"])
 
