@@ -134,6 +134,7 @@ class Sequencer:
 
 				self.block_tick()
 				i += 1
+		self.block.stop()
 		self.output_midi()
 
 	def output_midi(self):
@@ -173,7 +174,7 @@ class Sequencer:
 			'refresh_function': self.refresh_function,
 			'paint_function': self.paint_function,
 			'update_function': self.update_function,
-
+			'swing': self.block.swing,
 			}
 
 
@@ -200,7 +201,12 @@ class Sequencer:
 			# Should tick be skipped?
 		else:
 			tick_length -= exec_time
-		sleep(tick_length)
+		try:
+			sleep(tick_length)
+		except KeyboardInterrupt:
+			self.block.stop()
+			self.output_midi()
+			sys.exit(0)
 
 
 	def stop(self):
